;;;
;;; My key bindings, inspired by Brief on my '386 box.
;;;
;;;
;;; This file is set up for a Northgate OmniKey+ on a 386, running 386/ix
;;;
;; Function key mapping is to start with \C-^ as the first character.
;; This seems to not be used in the standard key maps.

;;; Function keys!
;; Praise the Lord and pass the ammunition!
;; This stuff here prevents the function keys from screwing up during search
;; and other minibuffer activities, as it does when for the default settings,
;; which have ESC as the first char.
;;
;; Shift Lock    1
;; Left Shift    2      Right Shift    4
;; Left Meta     8      Right Meta     16
;; Left Control  32     Right Control  64
;; Left Alt      128    Right Alt      256
;; 
(setq with-shift (epoch::mod-to-shiftmask 0))
(setq with-control (epoch::mod-to-shiftmask 2))
(setq with-meta (epoch::mod-to-shiftmask 3))
;(setq with-alt (epoch::mod-to-shiftmask 4))

;; Conventions: All rebound keys send control-^ first, followed by their
;; key value, lower for 1-9, uppercase for 10-19. Before the keycode, the
;; letter C is added for control keys, S for shifted keys, A for alt
;; M for Meta. An underscore indicates a normal key (e.g., Alt-l is
;; \C-^A_l (A for Alt, _ for letter, l for the keysym))

;; Warning - This rebinding depends on using xmodmap to switch keysyms.
;; Warning - What happens normally is that shift states cause the base
;; Warning - keysym to change. The modmap that I use forces the base keysyms
;; Warning - to be stable regardless of the shift state. The modmap is included
;; Warning - at the end of this file.
;;
;; special keys

(epoch::rebind-key "KP_Multiply" 0 "\C-^*")

; Home
(epoch::rebind-key "Home" 0 "\C-^7")
(epoch::rebind-key "Home" with-control "\C-^C7")

(epoch::rebind-key "Up" 0 "\C-^8")
(epoch::rebind-key "Up" with-shift "\C-^S8")
(epoch::rebind-key "Up" with-control "\C-^C8")
(epoch::rebind-key "Up" with-meta "\C-^M8")

; Page Up
(epoch::rebind-key "Prior" 0 "\C-^9")
(epoch::rebind-key "Prior" with-shift "\C-^S9")
(epoch::rebind-key "Prior" with-control "\C-^C9")
(epoch::rebind-key "Prior" with-meta "\C-^M9")

(epoch::rebind-key "Left" 0 "\C-^4")
(epoch::rebind-key "Left" with-control "\C-^4")
(epoch::rebind-key "Left" with-shift "\C-^S4")
(epoch::rebind-key "Left" with-meta "\C-^M4")

; center
(epoch::rebind-key "KP_5" 0 "\C-^5")
(epoch::rebind-key "KP_5" with-shift "\C-^S5")
(epoch::rebind-key "KP_5" with-control "\C-^C5")

(epoch::rebind-key "Right" 0 "\C-^6")
(epoch::rebind-key "Right" with-control "\C-^C6")
(epoch::rebind-key "Right" with-shift "\C-^S6")
(epoch::rebind-key "Right" with-meta "\C-^M6")

; end
(epoch::rebind-key "End" 0 "\C-^1")
(epoch::rebind-key "End" with-control "\C-^C1")

(epoch::rebind-key "Down" 0 "\C-^2")
(epoch::rebind-key "Down" with-shift "\C-^S2")
(epoch::rebind-key "Down" with-control "\C-^C2")

; Page Down
(epoch::rebind-key "Next" 0 "\C-^3")
(epoch::rebind-key "Next" with-shift "\C-^S3")
(epoch::rebind-key "Next" with-control "\C-^C3")
(epoch::rebind-key "Next" with-meta "\C-^M3")

(epoch::rebind-key "equal" with-control "\C-^C=")
(epoch::rebind-key "minus" with-control "\C-^C-")

;

(global-set-key "\C-^*" 'undo)		; keypad * on new suns

;; Normal cursor keys move characters and lines
(global-set-key "\C-^8" 'previous-line)
(global-set-key "\C-^2" 'next-line)
(global-set-key "\C-^4" 'backward-char)
(global-set-key "\C-^6" 'forward-char)

;; Shifted horizontal goes words
(global-set-key "\C-^S6" 'forward-word)
(global-set-key "\C-^S4" 'backward-word)
(global-set-key "\C-^S8" 'scroll-down-one)
(global-set-key "\C-^S2" 'scroll-up-one)
;; shifted page switches screens
(global-set-key "\C-^S9" (definteractive (select-screen (epoch::next-screen))))
					;shift page-up
(global-set-key "\C-^S3" (definteractive (select-screen (epoch::prev-screen))))
					;shift page-down

(global-set-key "\C-^7" 'beginning-of-line) ;Home
(global-set-key "\C-^5" 'recenter)	;Center
(global-set-key "\C-^1" 'end-of-line)	;End
(global-set-key "\C-^C7" 'beginning-of-buffer)	;control Home
(global-set-key "\C-^C1" 'end-of-buffer) ;control End
(global-set-key "\C-^S5" 'exchange-point-and-mark) ;shift center

(global-set-key "\C-^C9" (definteractive (raise-screen))) ;control page-up
(global-set-key "\C-^C3" (definteractive (lower-screen))) ;control page-down

(global-set-key "\C-^C=" 'split-window-vertically) ;control =
(global-set-key "\C-^C-" 'delete-other-windows)	;control -

(global-set-key "\C-^9" 'page-up)	;page-up
(global-set-key "\C-^3" 'page-down)	;page-down

; Mod Map file (remove semi-colons before use)
;
;add mod2 = Alt_L
;add mod2 = Alt_R
;keysym KP_7 = R7
;keysym KP_8 = Up
;keysym KP_9 = R9
;keysym KP_4 = Left
;keysym KP_5 = R11
;keysym KP_6 = Right
;keysym KP_1 = R13
;keysym KP_2 = Down
;keysym KP_3 = Next
